@@ -39,7 +39,7 @@ char copyright[] =
 #endif /* not lint */
 
 #ifndef lint
-static char rcsid[] = "$Id: edquota.c,v 1.1 1994/01/29 09:43:03 mvw Exp $";
+static char rcsid[] = "$Id: edquota.c,v 1.6 1995/07/23 09:58:06 mvw Exp mvw $";
 #endif /* not lint */
 
 /*
@@ -76,11 +76,11 @@ struct quotause {
 
 main(int  argc, char **argv)
 {
-   register struct quotause *qup, *protoprivs, *curprivs;
+   struct quotause *qup, *protoprivs, *curprivs;
    extern char *optarg;
    extern int optind;
-   register long id, protoid;
-   register int quotatype, tmpfd;
+   long id, protoid;
+   int quotatype, tmpfd;
    char *protoname, ch;
    int tflag = 0, pflag = 0;
 
@@ -199,8 +199,8 @@ getentry(char *name, int quotatype)
  */
 struct quotause *getprivs(long id, int quotatype)
 {
-   register struct mntent *mnt;
-   register struct quotause *qup, *quptail;
+   struct mntent *mnt;
+   struct quotause *qup, *quptail;
    FILE *fp;
    struct quotause *quphead;
    int qcmd, qupsize, fd;
@@ -208,14 +208,14 @@ struct quotause *getprivs(long id, int quotatype)
    static int warned = 0;
    extern int errno;
 
-   fp = setmntent(FSTAB, "r");
+   fp = setmntent(MNTTAB, "r");
    quphead = (struct quotause *) 0;
    qcmd = QCMD(Q_GETQUOTA, quotatype);
    while ((mnt = getmntent(fp)) != (struct mntent *) 0) {
       if (hasmntopt(mnt, MNTOPT_NOAUTO) || !hasquota(mnt, quotatype, &qfpathname))
          continue;
       qupsize = sizeof(*qup) + strlen(qfpathname);
-      if ((qup = (struct quotause *) malloc(qupsize)) == NULL) {
+      if ((qup = (struct quotause *) malloc(qupsize)) == (struct quotause *)NULL) {
          fprintf(stderr, "edquota: out of memory\n");
          exit(2);
       }
@@ -280,7 +280,7 @@ struct quotause *getprivs(long id, int quotatype)
  */
 putprivs(long id, int quotatype, struct quotause *quplist)
 {
-   register struct quotause *qup;
+   struct quotause *qup;
    int qcmd, fd;
 
    qcmd = QCMD(Q_SETQUOTA, quotatype);
@@ -318,7 +318,7 @@ editit(char *tmpfile)
       return (0);
    }
    if (pid == 0) {
-      register char  *ed;
+      char  *ed;
 
       sigsetmask(omask);
       setgid(getgid());
@@ -340,7 +340,7 @@ editit(char *tmpfile)
  */
 writeprivs(struct quotause *quplist, int outfd, char *name, int quotatype)
 {
-   register struct quotause *qup;
+   struct quotause *qup;
    FILE *fd;
 
    ftruncate(outfd, 0);
@@ -370,10 +370,10 @@ writeprivs(struct quotause *quplist, int outfd, char *name, int quotatype)
  */
 readprivs(struct quotause *quplist, int infd)
 {
-   register struct quotause *qup;
+   struct quotause *qup;
    FILE *fd;
    int cnt;
-   register char *cp;
+   char *cp;
    struct dqblk dqblk;
    char *fsp, line1[BUFSIZ], line2[BUFSIZ];
 
@@ -478,7 +478,7 @@ readprivs(struct quotause *quplist, int infd)
  */
 writetimes(struct quotause *quplist, int outfd, int quotatype)
 {
-   register struct quotause *qup;
+   struct quotause *qup;
    char *cvtstoa();
    FILE *fd;
 
@@ -507,10 +507,10 @@ writetimes(struct quotause *quplist, int outfd, int quotatype)
  */
 readtimes(struct quotause *quplist, int infd)
 {
-   register struct quotause *qup;
+   struct quotause *qup;
    FILE *fd;
    int cnt;
-   register char  *cp;
+   char  *cp;
    time_t itime, btime, iseconds, bseconds;
    char *fsp, bunits[10], iunits[10], line1[BUFSIZ];
 
@@ -618,7 +618,7 @@ cvtatos(time_t time, char *units, time_t *seconds)
  */
 freeprivs(struct quotause *quplist)
 {
-   register struct quotause *qup, *nextqup;
+   struct quotause *qup, *nextqup;
 
    for (qup = quplist; qup; qup = nextqup) {
       nextqup = qup->next;
@@ -631,7 +631,7 @@ freeprivs(struct quotause *quplist)
  */
 alldigits(char *s)
 {
-   register c;
+   int c;
 
    c = *s++;
    do {
